@@ -20,20 +20,26 @@ mod spawn;
 pub use spawn::*;
 
 #[allow(missing_docs)]
-#[cfg(any(test, feature = "test_utils"))]
+#[cfg(feature = "test_utils")]
 pub mod test_util;
 
 #[cfg(test)]
+#[cfg(feature = "test_utils")]
 mod test;
 
 pub mod fixt;
 
 /// 10MB of entropy free for the taking.
 /// Useful for initializing arbitrary::Unstructured data
-#[cfg(test)]
+#[cfg(any(test, feature = "test_utils"))]
 pub static NOISE: once_cell::sync::Lazy<Vec<u8>> = once_cell::sync::Lazy::new(|| {
     use rand::Rng;
+
     let mut rng = rand::thread_rng();
+
+    // use rand::SeedableRng;
+    // let mut rng = rand::rngs::StdRng::seed_from_u64(0);
+
     std::iter::repeat_with(|| rng.gen())
         .take(10_000_000)
         .collect()
