@@ -529,10 +529,10 @@ impl SwitchboardState {
         &mut self,
         QueryOpHashesEvt {
             space: _,
-            agents,
+            arc_set,
             window,
             max_ops,
-            include_limbo,
+            include_limbo: _,
         }: QueryOpHashesEvt,
     ) -> Option<(Vec<Arc<KitsuneOpHash>>, TimeWindow)> {
         let (ops, timestamps): (Vec<_>, Vec<_>) = self
@@ -543,22 +543,7 @@ impl SwitchboardState {
                 window.contains(&op.timestamp)
                     // Does the op fall within one of the specified arcsets
                     // with the correct integration/limbo criteria?
-                        && agents.iter().fold(false, |yes, (agent, arc_set)| {
-                            if yes {
-                                return true;
-                            }
-                            arc_set.contains((**op_loc8).into()) &&
-                            self.local_agent_by_hash(agent)
-                                .and_then(|agent| {
-                                    agent
-                                        .ops
-                                        // Does agent hold this op?
-                                        .get(op_loc8)
-                                        // Does it meet the limbo criteria of the query?
-                                        .map(|op| include_limbo || op.is_integrated)
-                                })
-                                .unwrap_or(false)
-                        })
+                        && arc_set.contains((**op_loc8).into())
             })
             .map(|(_, op)| (op.hash.clone(), op.timestamp))
             .take(max_ops)
